#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://sourceforge.net/projects/ogmrip/
# source location    : http://heanet.dl.sourceforge.net/sourceforge/ogmrip/ogmrip-0.13.2.tar.gz
# last revised       : 11.10.2009
# dep                : libdvdread,mplayer,mencoder, OGMTools,vorbistools,lame,enca,gpac,gocr 

softname='ogmrip'
softversion='0.13.2'
packageversion='1fb'

arch='i486'
cpu='i686'

prefix=/usr

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://heanet.dl.sourceforge.net/sourceforge/ogmrip/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
ogmrip: ogmrip (A movie encoder for GNOME)
ogmrip:
ogmrip: OGMRip is an application and a set of libraries for ripping and 
ogmrip: encoding DVD into AVI/OGM files using a wide variety of codecs. 
ogmrip: It relies on mplayer, mencoder, ogmtools, oggenc and lame 
ogmrip: to perform its tasks.
ogmrip: 
ogmrip:
ogmrip:
ogmrip:
ogmrip:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
  
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--disable-schemas-install \
	--with-gconf-source="xml::/etc/gconf/gconf.xml.defaults" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest
 
# gconf stuff
 export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
 if [ -d $dest/etc/gconf/schemas ]; then
     install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults
     SCHEMAS=$dest/etc/gconf/schemas
     for schema in $SCHEMAS/*.schemas; do
         gconftool-2 --makefile-install-rule $schema
     done
# Reset / Verify correct permissions
     ( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
     ( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )
 fi 
   
# make the .desktop file
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/$softname.png $softname.png

# make the .desktop file
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=OGMRip DVD Encoder
Comment=A DVD Encoder for GNOME
Comment[fr]=Encodeur de DVD pour GNOME
Exec=ogmrip
Terminal=false
Type=Application
Categories=Application;AudioVideo;
Icon=ogmrip
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion
	
#  strip
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# SalixBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "GConf,ORBit2,atk,cairo,cxxlibs|gcc-g++,dbus,dbus-glib,e2fsprogs,enca,\
enchant,expat,fontconfig,freetype,gcc,glib2,gocr,gtk+2,gpac,hal,libX11,libXau,\
libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,\
libXrandr,libXrender,libdvdread,libglade,libjpeg,libnotify,libogg,libpng,libtheora,\
libtiff,libxcb,libxml2,ogmtools,pango,pixman,zlib" > $package.dep

# .src
echo http://zenwalk.pinguix.com/user-accounts/bip/divers/salix/xap/ogmrip/build-ogmrip.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
